# arpes.endstations.plugin.kaindl module

**class arpes.endstations.plugin.kaindl.KaindlEndstation**

> Bases:
> [arpes.endstations.HemisphericalEndstation](arpes.endstations#arpes.endstations.HemisphericalEndstation),
> `arpes.endstations.SESEndstation`
> 
> The Robert Kaindl Endstation For HHG ARPES
> 
> `ALIASES = []`
> 
> `PRINCIPAL_NAME = 'Kaindl'`
> 
> `RENAME_KEYS = {'Delay Stage':
> 'delay'}`
> 
> **concatenate\_frames(frames=typing.List\[xarray.core.dataset.Dataset\],
> scan\_desc: dict = None)**
> 
> **postprocess\_final(data: xarray.core.dataset.Dataset, scan\_desc:
> dict = None)**
> 
> **resolve\_frame\_locations(scan\_desc: dict = None)**
